[![@wq/map-gl][logo]][docs]

**@wq/map-gl-web** provides web bindings for [@wq/map-gl], via the [Mapbox GL JS] library.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[Configuration][configuration]
&bull;
[Components][components]

[logo]: https://wq.io/images/@wq/map-gl.svg
[docs]: https://wq.io/@wq/map-gl
[installation]: https://wq.io/@wq/map-gl#installation
[api]: https://wq.io/@wq/map-gl#api
[configuration]: https://wq.io/@wq/map-gl#configuration
[components]: https://wq.io/@wq/map-gl#components

[@wq/map-gl]: https://wq.io/@wq/map-gl
[Mapbox GL JS]: https://docs.mapbox.com/mapbox-gl-js/
